@@ -185,7 +185,17 @@ class IotToKinesisStreams(
         :summary: Constructs a new instance of the IotToKinesisFirehoseToS3 class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotToKinesisStreams.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToKinesisStreamsProps(
@@ -250,7 +260,15 @@ class IotToKinesisStreamsProps:
         if isinstance(iot_topic_rule_props, dict):
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if __debug__:
-            type_hints = typing.get_type_hints(IotToKinesisStreamsProps.__init__)
+            def stub(
+                *,
+                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
